@@ -27,7 +27,7 @@ Usage::
     list_tasks_paginator: ListTasksPaginator = client.get_paginator("list_tasks")
     ```
 """
-from mypy_boto3_datasync.client import DataSyncClient as Client, DataSyncClient
+from mypy_boto3_datasync.client import DataSyncClient
 from mypy_boto3_datasync.paginator import (
     ListAgentsPaginator,
     ListLocationsPaginator,
@@ -36,6 +36,8 @@ from mypy_boto3_datasync.paginator import (
     ListTasksPaginator,
 )
 
+Client = DataSyncClient
+
 
 __all__ = (
     "Client",
